# api

## Purpose
OpenAPI and JSON schema generation/compatibility APIs.

## Owns
- OpenAPI document generation.
- Contract compatibility checks.
- Model JSON-schema projection.

## Entry Points
- `vyro.api.openapi`
- `vyro.api.openapi_compat`

## Not Here
- Request runtime execution.
